% vf.m
%
% Imlements the fisher-kpp traveling wave ODE
%   dx/dt = y
%   dy/dt =-cy - u(1-u)

%
% Inputs:
%   t - Time variable: not used here because our equation
%       is independent of time, or 'autonomous'.
%   x - Independent variable: has 3 dimensions
%   p - parameters, enter in the solver file
% Output:
%   dx - First derivative: the rate of change of the three dimension
%        values over time, given the values of each dimension
function dx = vf(t, x, p)

% Standard constants for the Lorenz Attractor
c = p(1);
%rho = p(2);
%beta = p(3);

% I like to initialize my arrays
dx = [0; 0];


dx(1) = x(2);
dx(2) = -c*x(2) - x(1).*(1-x(1));
%dx(3) = x(1)*x(2)-beta*x(3);
